vfSetGet = {};

function vfSetGet:generateDisplay()
	if VehicleFruitHud.values.horseHud ~= nil then return;end;	
	if g_currentMission.hud ~= nil and g_currentMission.hud.infoDisplay ~= nil then
		VehicleFruitHud.values.horseHud = g_currentMission.hud.infoDisplay:createBox(KeyValueInfoHUDBox);
		VehicleFruitHud.values.horseHud.cluster = AnimalClusterHorse.new();
		VehicleFruitHud.values.horseHud.cluster.infoAge = {text="",title=g_i18n:getText("infohud_age")};
		VehicleFruitHud.values.horseHud.cluster.infoTyp = {text="",title=g_i18n:getText("infohud_type")};
		VehicleFruitHud.values.horseHud.cluster.infoSpeed = {text="",title=g_i18n:getText("ui_hudSpeedGaugeSpeed")};
		VehicleFruitHud.values.horseHud.cluster.infoSellPrice = {text="",title=g_i18n:getText("ui_sellPrices")};
		VehicleFruitHud.values.horseHud:setTitle(tostring(VehicleFruitHud.metadata.title));		
	end;
end;

function vfSetGet:clearBox(box)
	for i = #box.activeLines, 1, -1 do
		box.cachedLines[#box.cachedLines + 1] = box.activeLines[i];
		box.activeLines[i] = nil;
	end;
end;

function vfSetGet:setBoxTitle(box, title)
	title = utf8ToUpper(title);
	if title ~= box.title then
		box.title = title;
		box.titleTextSize = vfSetGet:textBoxSizeToFit(box.labelTextSize, box.title, box.boxWidth);
	end;
end;

function vfSetGet:textBoxSizeToFit(baseSize, text, maxWidth, minSize)
	local size = baseSize;
	if minSize == nil then
		minSize = baseSize / 2;
	end;
	setTextWrapWidth(maxWidth);
	local lengthWithNoLineLimit = getTextLength(size, text, 99999);
	while getTextLength(size, text, 1) < lengthWithNoLineLimit do
		size = size - baseSize * 0.05;
		if size <= baseSize / 2 then
			size = size + baseSize * 0.05;
			break;
		end;
	end;
	setTextWrapWidth(0);
	return size;
end;

function vfSetGet:addBoxLine(box, key, value, otherColor)
	local line = nil;
	local cached = box.cachedLines;
	local numCached = #cached;
	if numCached > 0 then
		line = box.cachedLines[numCached];
		box.cachedLines[numCached] = nil;
	else
		line = {};
	end;
	line.key = key;
	line.value = value or "";	
	line.otherColor = otherColor;
	box.activeLines[#box.activeLines + 1] = line;
end;

function vfSetGet:getBoxDisplayHeight(box)
	return 2 * box.listMarginHeight + #box.activeLines * box.rowHeight + box.labelTextSize + box.labelTextOffsetY;
end;

function vfSetGet:getSupportsReproduction(vehicle)
	local subType = g_currentMission.animalSystem:getSubTypeByIndex(vehicle.cluster.subTypeIndex);
	return subType.supportsReproduction;
end;

function vfSetGet:getCanReproduce(vehicle, healthFactor)
	local subType = g_currentMission.animalSystem:getSubTypeByIndex(vehicle.cluster.subTypeIndex);
	if subType.supportsReproduction then		
		return subType.reproductionMinHealth <= healthFactor and subType.reproductionMinAgeMonth <= vehicle.cluster.age;
	end;
	return false;
end;

function vfSetGet:getSpeed(vehicle)
	local speed = Utils.getNoNil(vehicle.lastSpeed, 0)*3600;
	if g_gameSettings:getValue('useMiles') then speed = speed*0.621371;end;
	return string.format("%1.0f", "".. Utils.getNoNil(speed, 0));
end;

function vfSetGet:getSellPrice(vehicle, healthFactor, fitnessFactor)
	local subType = g_currentMission.animalSystem:getSubTypeByIndex(vehicle.cluster.subTypeIndex);
	local sellPrice = subType.sellPrice:get(vehicle.cluster.age);
	return sellPrice * (0.3 + 0.5 * healthFactor + 0.2 * fitnessFactor);
end

function vfSetGet:infoTxt()
	local isInfoTxt = false;
	if VehicleFruitHud.values.foundMoh and VehicleFruitHud.moh ~= nil then
		if g_currentMission.hl.textTicker.mods["MultiOverlayV4"] ~= nil and VehicleFruitHud.moh.moGeneralSettings.textTicker.isOn then
			VehicleFruitHud.moh.moGeneralSettings.textTicker.txt = "! VehicleFruitHud Info --> Found new/first Version, edit optimal a line values (Gui Menue) !";
			isInfoTxt = true;
		end;
	end;
	if not isInfoTxt then
		g_currentMission.hud:showInGameMessage("VehicleFruitHud Info", "Found new/first Version\nEdit optimal a line values (Gui Menue)", -1);
	end;
end;